Subject: [bug#62183] [PATCH v2 1/2] gnu: vtk: Enable OpenMP, TBB, and Open MPI support.

From: Ludovic Courtès <[email-masked]>
Date: Mon, 20 Mar 2023 23:09:55 +0100

From: Ludovic Courtès <[email-masked]>

* gnu/packages/image-processing.scm (vtk)[arguments]: Pass options to
enable OpenMP, TBB, and MPI.
[inputs]: Add OPENMPI.
[propagated-inputs]: Add TBB.
---
 gnu/packages/image-processing.scm | 15 +++++++++++----
 1 file changed, 11 insertions(+), 4 deletions(-)

Change since v1: TBB is now propagated, fixing builds of mia and f3d.

Ludo'.

diff --git a/gnu/packages/image-processing.scm b/gnu/packages/image-processing.scm
index 0562376291..c8786d8edd 100644
--- a/gnu/packages/image-processing.scm
+++ b/gnu/packages/image-processing.scm
@@ -1,7 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2017 John Darrington <[email-masked]>
 ;;; Copyright © 2017, 2019, 2022 Ricardo Wurmus <[email-masked]>
-;;; Copyright © 2014, 2021-2022 Ludovic Courtès <[email-masked]>
+;;; Copyright © 2014, 2021-2023 Ludovic Courtès <[email-masked]>
 ;;; Copyright © 2014 Mark H Weaver <[email-masked]>
 ;;; Copyright © 2016 Eric Bavier <[email-masked]>
 ;;; Copyright © 2018–2021 Tobias Geerinckx-Rice <[email-masked]>
@@ -380,6 +380,10 @@ (define-public vtk
                            "-DVTK_MODULE_ENABLE_VTK_RenderingExternal=YES" ; For F3D
                            "-DVTK_WRAP_PYTHON=ON"
                            "-DVTK_PYTHON_VERSION:STRING=3"
+
+                           "-DVTK_SMP_ENABLE_OPENNMP=ON"
+                           "-DVTK_SMP_ENABLE_TBB=ON"
+                           "-DVTK_USE_MPI=ON"
                            )
        #:tests? #f))        ;XXX: test data not included
     (inputs
@@ -402,17 +406,20 @@ (define-public vtk
            mesa
            netcdf
            libpng
+           libtiff
+           openmpi
            proj-7
            python
            ;("pugixml" ,pugixml)
            sqlite
-           libtiff
            xorgproto
            zlib))
     (propagated-inputs
      ;; VTK's 'VTK-vtk-module-find-packages.cmake' calls
-     ;; 'find_package(THEORA)', which in turns looks for libogg.
-     (list libogg))
+     ;; 'find_package(THEORA)', which in turns looks for libogg.  Likewise for
+     ;; TBB.
+     (list libogg
+           tbb))
     (home-page "https://vtk.org/")
     (synopsis "Libraries for 3D computer graphics")
     (description

base-commit: 99114eb63895712d2d3e62c5a83e3a1540438f15
-- 
2.39.2